Struct ArkoorPackageBuilder

pub struct ArkoorPackageBuilder<S: BuilderState> {
    pub builders: Vec<ArkoorBuilder<S>>,
}
A builder struct for creating arkoor packages

A package consists out of one or more inputs and matching outputs. When packages are created, the outputs can be possibly split up between the inputs.

The builder always keeps input and output order.

Fields

builders: Vec<ArkoorBuilder<S>>

Implementations

Source

impl ArkoorPackageBuilder<Initial>

pub fn new_with_checkpoints( inputs: impl IntoIterator<Item = Vtxo<Full>>, outputs: Vec<ArkoorDestination>, ) -> Result<Self, ArkoorConstructionError>

Create builder with checkpoints for multiple outputs

pub fn new_without_checkpoints( inputs: impl IntoIterator<Item = Vtxo<Full>>, outputs: Vec<ArkoorDestination>, ) -> Result<Self, ArkoorConstructionError>

Create builder without checkpoints for multiple outputs

pub fn new_single_output_with_checkpoints( inputs: impl IntoIterator<Item = Vtxo<Full>>, output: ArkoorDestination, change_policy: VtxoPolicy, ) -> Result<Self, ArkoorConstructionError>

Convenience constructor for single output with automatic change

Calculates change amount and creates appropriate output (backward-compatible with old API)

pub fn new_claim_all_with_checkpoints( inputs: impl IntoIterator<Item = Vtxo<Full>>, output_policy: VtxoPolicy, ) -> Result<Self, ArkoorConstructionError>

Convenience constructor for single output that claims all inputs

pub fn new_claim_all_without_checkpoints( inputs: impl IntoIterator<Item = Vtxo<Full>>, output_policy: VtxoPolicy, ) -> Result<Self, ArkoorConstructionError>

Convenience constructor for single output that claims all inputs

pub fn generate_user_nonces( self, user_keypairs: &[Keypair], ) -> Result<ArkoorPackageBuilder<UserGeneratedNonces>, ArkoorSigningError>

Source

impl ArkoorPackageBuilder<UserGeneratedNonces>

Source

impl ArkoorPackageBuilder<UserSigned>

Source

impl ArkoorPackageBuilder<ServerCanCosign>

Source

impl ArkoorPackageBuilder<ServerSigned>

Source

impl<S: BuilderState> ArkoorPackageBuilder<S>

pub fn input_ids<'a>(&'a self) -> impl Iterator<Item = VtxoId> + Clone + 'a

Access the input VTXO IDs

pub fn build_unsigned_vtxos<'a>( &'a self, ) -> impl Iterator<Item = Vtxo<Full>> + 'a

pub fn build_unsigned_internal_vtxos<'a>( &'a self, ) -> impl Iterator<Item = ServerVtxo<Full>> + 'a

Builds the unsigned internal VTXOs

Returns the checkpoint outputs (if checkpoints are used) and the dust isolation output (if dust isolation is used).

pub fn spend_info<'a>(&'a self) -> impl Iterator<Item = (VtxoId, Txid)> + 'a

Each VtxoId in the list is spent by Txid in an out-of-round transaction

pub fn virtual_transactions<'a>(&'a self) -> impl Iterator<Item = Txid> + 'a